@@ -29,24 +29,34 @@ AnnotationPropertiesFactory::AnnotationPropertiesFactory(Config *config, Abstrac
 	Q_ASSERT(mSettingsProvider != nullptr);
 }
 
-PropertiesPtr AnnotationPropertiesFactory::create(Tools toolType) const
+PropertiesPtr AnnotationPropertiesFactory::create(Tools tool) const
 {
-	auto properties = createPropertiesObject(toolType);
+	return create(tool, false);
+}
 
-	setColor(properties, toolType);
+PropertiesPtr AnnotationPropertiesFactory::createFromConfig(Tools tool) const
+{
+	return create(tool, true);
+}
+
+PropertiesPtr AnnotationPropertiesFactory::create(Tools tool, bool fromConfig) const
+{
+	auto properties = createPropertiesObject(tool);
+
+	setColor(properties, tool);
 	setTextColor(properties);
-	setWidthSize(properties, toolType);
-	setFill(properties, toolType);
-	setShadowEnabled(properties, toolType);
+	setWidthSize(properties);
+	setFill(properties, tool);
+	setShadowEnabled(properties, tool, fromConfig);
 	setPathProperties(properties);
-	setTextProperties(properties, toolType);
+	setTextProperties(properties, tool);
 	setObfuscateProperties(properties);
 	setStickerProperties(properties);
 
 	return properties;
 }
 
-PropertiesPtr AnnotationPropertiesFactory::createPropertiesObject(Tools toolType) const
+PropertiesPtr AnnotationPropertiesFactory::createPropertiesObject(Tools toolType)
 {
 	switch (toolType) {
 		case Tools::Pen:
@@ -73,8 +83,8 @@ void AnnotationPropertiesFactory::setColor(const PropertiesPtr &properties, Tool
 {
 	auto color = mSettingsProvider->toolColor();
 
-	if (isMarkerTool(toolType)) {
-		color.setAlpha(60);
+	if(toolType == Tools::Duplicate) {
+		color.setAlpha(30);
 	}
 
 	properties->setColor(color);
@@ -85,13 +95,9 @@ void AnnotationPropertiesFactory::setTextColor(const PropertiesPtr &properties)
 	properties->setTextColor(mSettingsProvider->textColor());
 }
 
-void AnnotationPropertiesFactory::setWidthSize(const PropertiesPtr &properties, Tools toolType) const
+void AnnotationPropertiesFactory::setWidthSize(const PropertiesPtr &properties) const
 {
-	if(toolType == Tools::MarkerPen) {
-		properties->setWidth(mSettingsProvider->toolWidth() * 3);
-	} else {
-		properties->setWidth(mSettingsProvider->toolWidth());
-	}
+	properties->setWidth(mSettingsProvider->toolWidth());
 }
 
 void AnnotationPropertiesFactory::setFill(const PropertiesPtr &properties, Tools toolType) const
@@ -104,6 +110,7 @@ void AnnotationPropertiesFactory::setFill(const PropertiesPtr &properties, Tools
 		case Tools::Sticker:
 		case Tools::NumberPointer:
 		case Tools::TextPointer:
+		case Tools::Duplicate:
 			properties->setFillType(mConfig->toolFillType(toolType));
 			break;
 		default:
@@ -111,13 +118,10 @@ void AnnotationPropertiesFactory::setFill(const PropertiesPtr &properties, Tools
 	}
 }
 
-void AnnotationPropertiesFactory::setShadowEnabled(const PropertiesPtr &properties, Tools toolType) const
+void AnnotationPropertiesFactory::setShadowEnabled(const PropertiesPtr &properties, Tools tool, bool fromConfig) const
 {
-	if (isObfuscateTool(toolType) || isMarkerTool(toolType) || toolType == Tools::Image) {
-		properties->setShadowEnabled(false);
-	} else {
-		properties->setShadowEnabled(mConfig->itemShadowEnabled());
-	}
+	auto enabled = fromConfig ? mConfig->shadowEnabled(tool) : mSettingsProvider->shadowEnabled();
+	properties->setShadowEnabled(enabled);
 }
 
 void AnnotationPropertiesFactory::setPathProperties(const PropertiesPtr &properties) const
@@ -133,9 +137,7 @@ void AnnotationPropertiesFactory::setTextProperties(const PropertiesPtr &propert
 {
 	auto textProperties = properties.dynamicCast<AnnotationTextProperties>();
 	if (textProperties != nullptr) {
-		auto font = mConfig->toolFont(toolType);
-		font.setPointSize(mSettingsProvider->fontSize());
-		textProperties->setFont(font);
+		textProperties->setFont(mSettingsProvider->font());
 	}
 }
 
@@ -155,14 +157,4 @@ void AnnotationPropertiesFactory::setStickerProperties(const PropertiesPtr &prop
 	}
 }
 
-bool AnnotationPropertiesFactory::isMarkerTool(Tools toolType)
-{
-	return toolType == Tools::MarkerPen || toolType == Tools::MarkerRect || toolType == Tools::MarkerEllipse;
-}
-
-bool AnnotationPropertiesFactory::isObfuscateTool(const Tools &toolType)
-{
-	return toolType == Tools::Blur || toolType == Tools::Pixelate;
-}
-
 } // namespace kImageAnnotator
