@@ -21,44 +21,54 @@
 
 namespace kImageAnnotator {
 
-QString ConfigNameHelper::annotator()
+QString ConfigNameHelper::kImageAnnotator()
 {
-	return QLatin1Literal("KImageAnnotator/");
+	return QLatin1String("KImageAnnotator/");
 }
 
 QString ConfigNameHelper::toolType()
 {
-	return annotator() + QLatin1Literal("ToolType");
+	return kImageAnnotator() + QLatin1String("ToolType");
 }
 
 QString ConfigNameHelper::toolWidth(Tools tool)
 {
-	return annotator() + QLatin1Literal("ToolWidth_") + QString::number(static_cast<int>(tool));
+	return kImageAnnotator() + QLatin1String("ToolWidth_") + QString::number(static_cast<int>(tool));
 }
 
 QString ConfigNameHelper::toolColor(Tools tool)
 {
-	return annotator() + QLatin1Literal("ToolColor_") + QString::number(static_cast<int>(tool));
+	return kImageAnnotator() + QLatin1String("ToolColor_") + QString::number(static_cast<int>(tool));
 }
 
 QString ConfigNameHelper::toolTextColor(Tools tool)
 {
-	return annotator() + QLatin1Literal("ToolTextColor_") + QString::number(static_cast<int>(tool));
+	return kImageAnnotator() + QLatin1String("ToolTextColor_") + QString::number(static_cast<int>(tool));
 }
 
 QString ConfigNameHelper::toolFillType(Tools tool)
 {
-	return annotator() + QLatin1Literal("ToolFillType_") + QString::number(static_cast<int>(tool));
+	return kImageAnnotator() + QLatin1String("ToolFillType_") + QString::number(static_cast<int>(tool));
 }
 
-QString ConfigNameHelper::toolFontSize(Tools tool)
+QString ConfigNameHelper::toolFont(Tools tool)
 {
-	return annotator() + QLatin1Literal("ToolFontSize_") + QString::number(static_cast<int>(tool));
+	return kImageAnnotator() + QLatin1String("ToolFont_") + QString::number(static_cast<int>(tool));
 }
 
 QString ConfigNameHelper::obfuscateFactor(Tools tool)
 {
-	return annotator() + QLatin1Literal("ToolObfuscateFactor_") + QString::number(static_cast<int>(tool));
+	return kImageAnnotator() + QLatin1String("ToolObfuscateFactor_") + QString::number(static_cast<int>(tool));
+}
+
+QString ConfigNameHelper::shadowEnabled(Tools tool)
+{
+	return kImageAnnotator() + QLatin1String("ToolShadowEnabled_") + QString::number(static_cast<int>(tool));
+}
+
+QString ConfigNameHelper::annotatorDockWidgetsState()
+{
+	return kImageAnnotator() + QLatin1String("AnnotatorDockWidgetsState");
 }
 
 }
\ No newline at end of file
