@@ -93,8 +93,8 @@ void AnnotationPropertiesFactoryTest::TestCreate_Should_SetShadowEnabledBasedOnC
 	auto tool = Tools::Pen;
 	auto config = new Config;
 	auto enabled = true;
-	config->setItemShadowEnabled(enabled);
 	auto settingsProvider = new MockSettingsProvider();
+	settingsProvider->setShadowEnabled(enabled);
 	AnnotationPropertiesFactory propertiesFactory(config, settingsProvider);
 
 	auto properties = propertiesFactory.create(tool);
@@ -191,14 +191,13 @@ void AnnotationPropertiesFactoryTest::TestCreate_Should_SetSmoothPathBasedOnConf
 	QCOMPARE(pathProperties->smoothFactor(), smoothPathFactor);
 }
 
-void AnnotationPropertiesFactoryTest::TestCreate_Should_SetToolFontAndFontSizeBasedOnConfiguration()
+void AnnotationPropertiesFactoryTest::TestCreate_Should_SetToolFontBasedOnSettings()
 {
 	auto tool = Tools::Number;
 	auto config = new Config;
 	auto font = QFont("Helvetica [Cronyx]", 8, QFont::StyleItalic);
-	config->setToolFont(font, tool);
 	auto settingsProvider = new MockSettingsProvider();
-	settingsProvider->setFontSize(8);
+	settingsProvider->setFont(font);
 	AnnotationPropertiesFactory propertiesFactory(config, settingsProvider);
 
 	auto properties = propertiesFactory.create(tool);
